@@ -358,7 +358,13 @@ class Messages(Hierarcy):
     class Meta:
         verbose_name = 'Сообщения'
         constraints = [
-            UniqueConstraint(fields=['checksum', 'state', 'theme', 'to_whom', 'user'], condition=Q(guid=None), name='Messages_unique_constraint_0'),
-            UniqueConstraint(fields=['checksum', 'guid', 'state', 'theme', 'to_whom', 'user'], name='Messages_unique_constraint_1'),
+            UniqueConstraint(fields=['checksum', 'state', 'theme', 'to_whom', 'user'], condition=Q(guid=None) & Q(importance=None) & Q(message=None), name='Messages_unique_constraint_0'),
+            UniqueConstraint(fields=['checksum', 'guid', 'state', 'theme', 'to_whom', 'user'], condition=Q(importance=None) & Q(message=None), name='Messages_unique_constraint_1'),
+            UniqueConstraint(fields=['checksum', 'importance', 'state', 'theme', 'to_whom', 'user'], condition=Q(guid=None) & Q(message=None), name='Messages_unique_constraint_2'),
+            UniqueConstraint(fields=['checksum', 'guid', 'importance', 'state', 'theme', 'to_whom', 'user'], condition=Q(message=None), name='Messages_unique_constraint_3'),
+            UniqueConstraint(fields=['checksum', 'message', 'state', 'theme', 'to_whom', 'user'], condition=Q(guid=None) & Q(importance=None), name='Messages_unique_constraint_4'),
+            UniqueConstraint(fields=['checksum', 'guid', 'message', 'state', 'theme', 'to_whom', 'user'], condition=Q(importance=None), name='Messages_unique_constraint_5'),
+            UniqueConstraint(fields=['checksum', 'importance', 'message', 'state', 'theme', 'to_whom', 'user'], condition=Q(guid=None), name='Messages_unique_constraint_6'),
+            UniqueConstraint(fields=['checksum', 'guid', 'importance', 'message', 'state', 'theme', 'to_whom', 'user'], name='Messages_unique_constraint_7'),
         ]
         ordering = ('lastmodified',)
